@@ -5,14 +5,15 @@ from collections.abc import Iterable
 
 import numpy as np
 import pandas as pd
+import pyarrow as pa
+import pyarrow.compute
 from pandas.api.types import is_scalar, union_categoricals
 
-from dask.array.core import Array
+from dask.array import Array
 from dask.array.dispatch import percentile_lookup
 from dask.array.percentile import _percentile
 from dask.backends import CreationDispatch, DaskBackendEntrypoint
 from dask.dataframe._compat import PANDAS_GE_220, is_any_real_numeric_dtype
-from dask.dataframe.core import DataFrame, Index, Scalar, Series, _Frame
 from dask.dataframe.dispatch import (
     categorical_dtype_dispatch,
     concat,
@@ -190,6 +191,21 @@ def _(x):
 @make_meta_dispatch.register((pd.Series, pd.DataFrame))
 def _(x, index=None):
     out = x.iloc[:0].copy(deep=True)
+
+    # https://github.com/pandas-dev/pandas/issues/61930
+    # pandas shallow copies arrow-backed extension arrays.
+    # Use pyarrow.compute.take to get a new array that doesn't
+    # share any memory with the original array.
+
+    for k, v in out.items():
+        if isinstance(v.array, pd.arrays.ArrowExtensionArray):
+            values = pyarrow.compute.take(
+                pyarrow.array(v.array), pyarrow.array([], type="int32")
+            )
+            out[k] = v._constructor(
+                pd.array(values, dtype=v.array.dtype), index=v.index, name=v.name
+            )
+
     # index isn't copied by default in pandas, even if deep=true
     out.index = out.index.copy(deep=True)
     return out
@@ -227,7 +243,6 @@ def get_pyarrow_table_from_pandas(obj, **kwargs):
 @from_pyarrow_table_dispatch.register((pd.DataFrame,))
 def get_pandas_dataframe_from_pyarrow(meta, table, **kwargs):
     # `kwargs` must be supported by `pyarrow.Table.to_pandas`
-    import pyarrow as pa
 
     def default_types_mapper(pyarrow_dtype: pa.DataType) -> object:
         # Avoid converting strings from `string[pyarrow]` to
@@ -282,7 +297,7 @@ def make_meta_object(x, index=None):
     >>> make_meta_object(('a', 'f8'))
     Series([], Name: a, dtype: float64)
     >>> make_meta_object('i8')
-    1
+    np.int64(1)
     """
 
     if is_arraylike(x) and x.shape:
@@ -371,7 +386,12 @@ def _nonempty_index(idx):
         # `self.monotonic_increasing` or `self.monotonic_decreasing`
         try:
             return pd.date_range(
-                start=start, periods=2, freq=idx.freq, tz=idx.tz, name=idx.name
+                start=start,
+                periods=2,
+                freq=idx.freq,
+                tz=idx.tz,
+                name=idx.name,
+                unit=idx.unit,
             )
         except ValueError:  # older pandas versions
             data = [start, "1970-01-02"] if idx.freq is None else None
@@ -436,7 +456,7 @@ def _nonempty_series(s, idx=None):
         data = [s.iloc[0]] * 2
     elif isinstance(dtype, pd.DatetimeTZDtype):
         entry = pd.Timestamp("1970-01-01", tz=dtype.tz)
-        data = [entry, entry]
+        data = pd.array([entry, entry], dtype=dtype)
     elif isinstance(dtype, pd.CategoricalDtype):
         if len(s.cat.categories):
             data = [s.cat.categories[0]] * 2
@@ -493,26 +513,29 @@ def union_categoricals_pandas(to_union, sort_categories=False, ignore_order=Fals
 
 @get_parallel_type.register(pd.Series)
 def get_parallel_type_series(_):
+    from dask.dataframe.dask_expr._collection import Series
+
     return Series
 
 
 @get_parallel_type.register(pd.DataFrame)
 def get_parallel_type_dataframe(_):
+    from dask.dataframe.dask_expr._collection import DataFrame
+
     return DataFrame
 
 
 @get_parallel_type.register(pd.Index)
 def get_parallel_type_index(_):
+    from dask.dataframe.dask_expr._collection import Index
+
     return Index
 
 
-@get_parallel_type.register(_Frame)
-def get_parallel_type_frame(o):
-    return get_parallel_type(o._meta)
-
-
 @get_parallel_type.register(object)
 def get_parallel_type_object(_):
+    from dask.dataframe.dask_expr._collection import Scalar
+
     return Scalar
 
 
@@ -558,6 +581,38 @@ def group_split_pandas(df, c, k, ignore_index=False):
     return ShuffleGroupResult(zip(range(k), parts))
 
 
+def _union_categoricals_wrapper(
+    dfs: list[pd.CategoricalIndex] | list[pd.Series], **kwargs
+) -> pd.Categorical:
+    """
+    A wrapper around pandas' union_categoricals that handles some dtype issues.
+
+    union_categoricals requires that the dtype of each array's categories match.
+    So you can't union ``Categorical(['a', 'b'])`` and ``Categorical([1, 2])``
+    since the dtype (str vs. int) doesn't match.
+
+    *Somewhere* in Dask, we're possibly creating an empty ``Categorical``
+    with a dtype of ``object``. In pandas 2.x, we could union that with string
+    categories since they both used object dtype. But pandas 3.x uses string
+    dtype for categories.
+
+    This wrapper handles that by creating a new ``Categorical`` with the
+    correct dtype.
+    """
+    categories_dtypes = {cat.dtype.categories.dtype.name for cat in dfs}
+    if "object" in categories_dtypes and "str" in categories_dtypes:
+        dfs = [
+            (
+                type(cat)(pd.Categorical(pd.Index([], dtype="str")), name=cat.name)
+                if cat.dtype.categories.dtype.name == "object" and len(cat) == 0
+                else cat
+            )
+            for cat in dfs
+        ]
+
+    return union_categoricals(dfs, **kwargs)
+
+
 @concat_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
 def concat_pandas(
     dfs,
@@ -580,7 +635,8 @@ def concat_pandas(
                 if not isinstance(dfs[i], pd.CategoricalIndex):
                     dfs[i] = dfs[i].astype("category")
             return pd.CategoricalIndex(
-                union_categoricals(dfs, ignore_order=ignore_order), name=dfs[0].name
+                _union_categoricals_wrapper(dfs, ignore_order=ignore_order),
+                name=dfs[0].name,
             )
         elif isinstance(dfs[0], pd.MultiIndex):
             first, rest = dfs[0], dfs[1:]
@@ -631,9 +687,11 @@ def concat_pandas(
             # converts series to dataframes with a single column named 0, then
             # concatenates.
             dfs3 = [
-                df
-                if isinstance(df, pd.DataFrame)
-                else df.to_frame().rename(columns={df.name: 0})
+                (
+                    df
+                    if isinstance(df, pd.DataFrame)
+                    else df.to_frame().rename(columns={df.name: 0})
+                )
                 for df in dfs2
             ]
             # pandas may raise a RuntimeWarning for comparing ints and strs
@@ -673,7 +731,7 @@ def concat_pandas(
                             codes, sample.cat.categories, sample.cat.ordered
                         )
                         parts.append(data)
-                out[col] = union_categoricals(parts, ignore_order=ignore_order)
+                out[col] = _union_categoricals_wrapper(parts, ignore_order=ignore_order)
                 # Pandas resets index type on assignment if frame is empty
                 # https://github.com/pandas-dev/pandas/issues/17101
                 if not len(temp_ind):
@@ -734,6 +792,8 @@ def get_grouper_pandas(obj):
 
 @percentile_lookup.register((pd.Series, pd.Index))
 def percentile(a, q, interpolation="linear"):
+    if isinstance(a.dtype, pd.ArrowDtype):
+        a = a.to_numpy()
     return _percentile(a, q, interpolation)
 
 
@@ -755,7 +815,7 @@ class PandasBackendEntrypoint(DataFrameBackendEntrypoint):
         return to_pandas_dispatch
 
     @classmethod
-    def to_backend(cls, data: _Frame, **kwargs):
+    def to_backend(cls, data, **kwargs):
         if isinstance(data._meta, (pd.DataFrame, pd.Series, pd.Index)):
             # Already a pandas-backed collection
             return data
@@ -771,13 +831,16 @@ dataframe_creation_dispatch.register_backend("pandas", PandasBackendEntrypoint()
 
 
 @concat_dispatch.register_lazy("cudf")
-@hash_object_dispatch.register_lazy("cudf")
+@from_pyarrow_table_dispatch.register_lazy("cudf")
 @group_split_dispatch.register_lazy("cudf")
 @get_parallel_type.register_lazy("cudf")
+@hash_object_dispatch.register_lazy("cudf")
 @meta_nonempty.register_lazy("cudf")
 @make_meta_dispatch.register_lazy("cudf")
 @make_meta_obj.register_lazy("cudf")
 @percentile_lookup.register_lazy("cudf")
+@to_pandas_dispatch.register_lazy("cudf")
+@to_pyarrow_table_dispatch.register_lazy("cudf")
 @tolist_dispatch.register_lazy("cudf")
 def _register_cudf():
     import dask_cudf  # noqa: F401
